==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/experiments/dialogs_nl.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Dit lijkt wel een laboratorium ofzo.")


dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Blijkbaar hebben vliegende schotels een laboratorium aan boord.")


dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Dit ziet er uit als een laboratorium.")


dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Deze experimenten zien er een beetje verdacht uit.")


dialogId("bank-v-pokusy2", "font_big", "I think that someone`s carrying out some rather suspicious experiments here.")
dialogStr("Ik denk dat iemand hier nogal verdachte experimenten heeft lopen doen.")


dialogId("bank-m-jejda", "font_small", "My gosh, what`s this?!?")
dialogStr("Lieve Hemel, wat is dit?!?")


dialogId("bank-v-zije", "font_big", "Everything`s alive here.")
dialogStr("Alles hier leeft.")


dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Ssst, ik wil dit laboratorium goed onderzoeken.")


dialogId("bank-m-bojim", "font_small", "I`m little bit afraid of that thing behind the door...")
dialogStr("Ik ben een beetje bang voor dat ding daar achter die deur...")


dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("Waarom heeft het drie ogen?")


dialogId("bank-v-pomoc", "font_big", "Stop what you`re doing down there and come help me!")
dialogStr("Hou op met dat gedoe daar beneden en kom mij eens helpen!")


dialogId("bank-m-organismy", "font_small", "I would never have thought that we`d find so many living things inside a UFO...")
dialogStr("Ik had niet gedacht dat we zo veel levende wezens zouden vinden in een vliegende schotel...")


dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("Er zijn hier ongeloofelijk veel verschillende beesten!")


dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("Jeetje, moet je zien hoe die zich voortplanten!")


dialogId("bank-m-nesetkala", "font_small", "I`ve never seen this kind of organism before.")
dialogStr("Zo'n organisme heb ik nog nooit gezien.")


dialogId("bank-m-kouka", "font_small", "Help! It`s looking at me!")
dialogStr("Help! Het kijkt naar me!")


dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("Bah!.")


dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Ik vind deze hand eng...")


dialogId("bank-m-zkumavka", "font_small", "There`s a strange odor coming from this test-tube...")
dialogStr("Uit dit reageerbuisje komt wel een hele rare geur...")


dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Ik ben duizelig...")


dialogId("bank-v-neproplavu1", "font_big", "I can`t swim through here. We`re going to have to push this aside.")
dialogStr("Ik kan hier niet tussendoor zwemmen. We zullen dit opzij moeten duwen.")


dialogId("bank-v-neproplavu2", "font_big", "I can`t swim through here. We`re going to have to push this down.")
dialogStr("Ik kan hier niet tussendoor zwemmen. We zullen dit naar beneden moeten duwen.")


dialogId("bank-v-nahazet", "font_big", "We`re going to need to throw on a lot more of these things.")
dialogStr("We zullen nog meer van dit soort dingen erop moeten gooien.")


dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Meer.")


dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("We moeten alles hier goed bekijken.")


dialogId("bank-v-vypad1", "font_big", "I`d rather get out of here.")
dialogStr("Ik wil hier liever weg.")


dialogId("bank-v-vypad2", "font_big", "You know, I`d really rather get out of here.")
dialogStr("Weet je, ik wil hier liever weg.")


dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("Ik word misselijk van de stank uit dat flesje.")


dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Woeps, kapot...")


dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Ik denk dat sommige van de wezens hier het gevolg zijn van genetische manipulatie.")


dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("Dit is gewoon te erg!")


dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("Hoe afgrijselijk!")


dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Dat lijk ken ik ergens van.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/experiments/dialogs_nl.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Dit lijkt wel een laboratorium ofzo.")


dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Blijkbaar hebben vliegende schotels een laboratorium aan boord.")


dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Dit ziet er uit als een laboratorium.")


dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Deze experimenten zien er een beetje verdacht uit.")


dialogId("bank-v-pokusy2", "font_big", "I think that someone’s carrying out some rather suspicious experiments here.")
dialogStr("Ik denk dat iemand hier nogal verdachte experimenten aan het doen is.")


dialogId("bank-m-jejda", "font_small", "My gosh, what’s this?!?")
dialogStr("Lieve Hemel, wat is dit?!?")


dialogId("bank-v-zije", "font_big", "Everything’s alive here.")
dialogStr("Alles hier leeft.")


dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Ssst, ik wil dit laboratorium goed onderzoeken.")


dialogId("bank-m-bojim", "font_small", "I’m little bit afraid of that thing behind the door...")
dialogStr("Ik ben een beetje bang voor dat ding daar achter die deur...")


dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("Waarom heeft het drie ogen?")


dialogId("bank-v-pomoc", "font_big", "Stop what you’re doing down there and come help me!")
dialogStr("Hou op met dat gedoe daar beneden en kom mij eens helpen!")


dialogId("bank-m-organismy", "font_small", "I would never have thought that we’d find so many living things inside a UFO...")
dialogStr("Ik had niet gedacht dat we zo veel levende wezens zouden vinden in een vliegende schotel...")


dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("Er zijn hier ongeloofelijk veel verschillende beesten!")


dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("Jeetje, moet je zien hoe die zich voortplanten!")


dialogId("bank-m-nesetkala", "font_small", "I’ve never seen this kind of organism before.")
dialogStr("Zo'n organisme heb ik nog nooit gezien.")


dialogId("bank-m-kouka", "font_small", "Help! It’s looking at me!")
dialogStr("Help! Het kijkt naar me!")


dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("Bah.")


dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Ik vind deze hand eng...")


dialogId("bank-m-zkumavka", "font_small", "There’s a strange odor coming from this test-tube...")
dialogStr("Uit dit reageerbuisje komt wel een hele rare geur...")


dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Ik word hier duizelig van...")


dialogId("bank-v-neproplavu1", "font_big", "I can’t swim through here. We’re going to have to push this aside.")
dialogStr("Ik kan hier niet tussendoor zwemmen. We zullen dit opzij moeten duwen.")


dialogId("bank-v-neproplavu2", "font_big", "I can’t swim through here. We’re going to have to push this down.")
dialogStr("Ik kan hier niet tussendoor zwemmen. We zullen dit naar beneden moeten duwen.")


dialogId("bank-v-nahazet", "font_big", "We’re going to need to throw on a lot more of these things.")
dialogStr("We zullen nog meer van dit soort dingen erop moeten gooien.")


dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Meer.")


dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("We moeten alles hier goed bekijken.")


dialogId("bank-v-vypad1", "font_big", "I’d rather get out of here.")
dialogStr("Ik wil hier liever weg.")


dialogId("bank-v-vypad2", "font_big", "You know, I’d really rather get out of here.")
dialogStr("Weet je, ik wil hier liever weg.")


dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("Ik word misselijk van de stank uit dat flesje.")


dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Woeps, kapot...")


dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Ik denk dat sommige van de wezens hier het gevolg zijn van genetische manipulatie.")


dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("Dit is gewoon te erg!")


dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("Hoe afgrijselijk!")


dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Dat lijk ken ik ergens van.")
